=======
Credits
=======

Based on code originally by Stefan Foulis

Development Lead
----------------

* Iacopo Spalletti <i.spalletti@nephila.it>

Contributors
------------

* Mark Walker <theshow@gmail.com>
